@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 module DBF
   module Memo
     class Dbase3 < Base
       def build_memo(start_block) # :nodoc:
         @data.seek offset(start_block)
-        memo_string = ''
+        memo_string = +''
         loop do
           block = @data.read(BLOCK_SIZE).gsub(/(\000|\032)/, '')
           memo_string << block
