@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module DBF
   class FileNotFoundError < StandardError
   end
@@ -76,7 +78,7 @@ module DBF
     # @param encoding [optional String, Encoding] encoding Name of the encoding or an Encoding object
     def initialize(data, memo = nil, encoding = nil)
       @data = open_data(data)
-      @encoding = encoding || header.encoding
+      @encoding = encoding || header.encoding || Encoding.default_external
       @memo = open_memo(data, memo)
       yield self if block_given?
     end
@@ -211,6 +213,21 @@ module DBF
       VERSIONS[version]
     end
 
+    # Encode string
+    #
+    # @param [String] string
+    # @return [String]
+    def encode_string(string) # :nodoc:
+      string.force_encoding(@encoding).encode(Encoding.default_external, undef: :replace, invalid: :replace)
+    end
+
+    # Encoding specified in the file header
+    #
+    # @return [Encoding]
+    def header_encoding
+      header.encoding
+    end
+
     private
 
     def build_columns # :nodoc:
@@ -280,10 +297,9 @@ module DBF
     def memo_class # :nodoc:
       @memo_class ||= if foxpro?
         Memo::Foxpro
-        else
-          version == '83' ? Memo::Dbase3 : Memo::Dbase4
+      else
+        version == '83' ? Memo::Dbase3 : Memo::Dbase4
       end
-      
     end
 
     def memo_search_path(io) # :nodoc:
@@ -293,7 +309,14 @@ module DBF
     end
 
     def open_data(data) # :nodoc:
-      data.is_a?(StringIO) ? data : File.open(data, 'rb')
+      case data
+      when StringIO
+        data
+      when String
+        File.open(data, 'rb')
+      else
+        raise ArgumentError, 'data must be a file path or StringIO object'
+      end
     rescue Errno::ENOENT
       raise DBF::FileNotFoundError, "file not found: #{data}"
     end
