@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 RSpec.describe DBF::Table do
@@ -29,6 +31,12 @@ RSpec.describe DBF::Table do
       end
     end
 
+    describe 'when data is nil' do
+      it 'raises ArgumentError' do
+        expect { DBF::Table.new nil }.to raise_error(ArgumentError, 'data must be a file path or StringIO object')
+      end
+    end
+
     describe 'when given paths to existing dbf and memo files' do
       it 'does not raise an error' do
         expect { DBF::Table.new dbf_path, memo_path }.to_not raise_error
@@ -136,7 +144,7 @@ RSpec.describe DBF::Table do
       before { table.to_csv('test.csv') }
 
       it 'creates a custom csv file' do
-        expect(File).to be_exist('test.csv')
+        expect(File).to exist('test.csv')
       end
     end
   end
